==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fbyteindex.h <==
// class soot.coffi.Instruction_byteindex

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 34236df30d2a0a89 soot_coffi_Instruction__5fbyteindex

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fbyteindex_H_
#define _JC_soot_coffi_Instruction__5fbyteindex_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$sub_refs	_jc_soot_coffi_Instruction__5fbyteindex$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs	_jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$refs	_jc_soot_coffi_Instruction__5fbyteindex$refs;
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$nonrefs	_jc_soot_coffi_Instruction__5fbyteindex$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$object	_jc_soot_coffi_Instruction__5fbyteindex$object;

typedef const struct _jc_soot_coffi_Instruction__5fbyteindex$vmethods	_jc_soot_coffi_Instruction__5fbyteindex$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fbyteindex$vtable	_jc_soot_coffi_Instruction__5fbyteindex$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fbyteindex$vtype	_jc_soot_coffi_Instruction__5fbyteindex$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fbyteindex$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, jbyte);

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fbyteindex$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_byte_array *, jint);
extern void _jc_soot_coffi_Instruction__5fbyteindex$method$markCPRefs$b0e03bf500f63087(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_boolean_array *);
extern jint _jc_soot_coffi_Instruction__5fbyteindex$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, jint);
extern jint _jc_soot_coffi_Instruction__5fbyteindex$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_byte_array *, jint);
extern void _jc_soot_coffi_Instruction__5fbyteindex$method$redirectCPRefs$777e17d486bcc287(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_short_array *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbyteindex$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$markCPRefs$b0e03bf500f63087;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$redirectCPRefs$777e17d486bcc287;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fbyteindex$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_byte_array *, jint);
	void	(*markCPRefs$b0e03bf500f63087)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_boolean_array *);
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, jint);
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_byte_array *, jint);
	void	(*redirectCPRefs$777e17d486bcc287)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_short_array *);
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fbyteindex$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbyteindex$vmethods	soot_coffi_Instruction__5fbyteindex;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fbyteindex$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fbyteindex$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbyteindex$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbyteindex$refs {
    _jc_soot_coffi_Instruction__5fbyteindex$sub_refs	soot_coffi_Instruction__5fbyteindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs {
	jshort	arg__5fb;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbyteindex$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs	soot_coffi_Instruction__5fbyteindex;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fbyteindex$object {
	_jc_soot_coffi_Instruction__5fbyteindex$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fbyteindex$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fbyteindex$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fbyteindex$vtype _jc_soot_coffi_Instruction__5fbyteindex$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fbyteindex, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fbyteindex$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fbyteindex_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fbyteindex.h <==
// class soot.coffi.Instruction_byteindex

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 34236df30d2a0a89 soot_coffi_Instruction__5fbyteindex

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fbyteindex_H_
#define _JC_soot_coffi_Instruction__5fbyteindex_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$sub_refs	_jc_soot_coffi_Instruction__5fbyteindex$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs	_jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$refs	_jc_soot_coffi_Instruction__5fbyteindex$refs;
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$nonrefs	_jc_soot_coffi_Instruction__5fbyteindex$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbyteindex$object	_jc_soot_coffi_Instruction__5fbyteindex$object;

typedef const struct _jc_soot_coffi_Instruction__5fbyteindex$vmethods	_jc_soot_coffi_Instruction__5fbyteindex$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fbyteindex$vtable	_jc_soot_coffi_Instruction__5fbyteindex$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fbyteindex$vtype	_jc_soot_coffi_Instruction__5fbyteindex$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fbyteindex$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, jbyte) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fbyteindex$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Instruction__5fbyteindex$method$markCPRefs$b0e03bf500f63087(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_boolean_array *) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fbyteindex$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fbyteindex$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Instruction__5fbyteindex$method$redirectCPRefs$777e17d486bcc287(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_short_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbyteindex$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$markCPRefs$b0e03bf500f63087;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$redirectCPRefs$777e17d486bcc287;
extern _jc_method _jc_soot_coffi_Instruction__5fbyteindex$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fbyteindex$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	void	(*markCPRefs$b0e03bf500f63087)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_boolean_array *) _JC_JCNI_ATTR;
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, jint) _JC_JCNI_ATTR;
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	void	(*redirectCPRefs$777e17d486bcc287)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_short_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyteindex$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fbyteindex$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbyteindex$vmethods	soot_coffi_Instruction__5fbyteindex;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fbyteindex$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fbyteindex$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbyteindex$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbyteindex$refs {
    _jc_soot_coffi_Instruction__5fbyteindex$sub_refs	soot_coffi_Instruction__5fbyteindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs {
	jshort	arg__5fb;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbyteindex$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs	soot_coffi_Instruction__5fbyteindex;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fbyteindex$object {
	_jc_soot_coffi_Instruction__5fbyteindex$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fbyteindex$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fbyteindex$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fbyteindex$vtype _jc_soot_coffi_Instruction__5fbyteindex$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fbyteindex, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fbyteindex$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fbyteindex_H_ */
